package com.ruoyi.web.controller.dragForm;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.ruoyi.common.constant.ButtonTypeConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.exception.tenantdatassource.TenantDataSource;
import com.ruoyi.system.entity.CommonEntity;
import com.ruoyi.system.entity.DragForm;
import com.ruoyi.system.entity.TableSql;
import com.ruoyi.system.service.*;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

@RestController
@RequestMapping("/dragform/common")
public class CommonController extends BaseController {

    @Resource
    private ICommonService commonService;

    @Resource  // 动态sql
    private ITableSqlService iTableSqlService;

    @Resource // 动态表格
    private IDragTableService dragTableService;

    @Resource
    private IDragTableGroupService dragTableGroupService;

    @Resource
    private IDragFormService dragFormService;

    /**
     * 共通查询
     */
    @GetMapping("/selectList")
    public TableDataInfo selectList(CommonEntity commonEntity) {
        startPage();
        return getDataTable(commonService.selectList(commonEntity));
    }

    /**
     * 共通批量新增
     */
    @PostMapping("/batchInsert")
    public AjaxResult batchInsert(@RequestBody CommonEntity commonEntity) {
        return toAjax(commonService.batchInsert(commonEntity));
    }

    /**
     * 共通修改sql
     */
    @PutMapping("/batchEdit")
    public AjaxResult edit(@RequestBody CommonEntity commonEntity) {
        return toAjax(commonService.edit(commonEntity));
    }

    /**
     * 批量删除
     */
    @DeleteMapping("/batchDelete")
    public AjaxResult batchDelete(@RequestBody CommonEntity commonEntity) {
        return toAjax(commonService.batchDelete(commonEntity));
    }

    /**
     * 共通获取详情
     */
    @GetMapping("/getInfo")
    public AjaxResult getInfo(CommonEntity commonEntity){
        return success(commonService.getInfoById(commonEntity));
    }

    /**
     * 联合查询通用sql
     *
     * @param commonEntity
     * @return
     */
    @GetMapping("/getTableList")
    public TableDataInfo queryTableList(CommonEntity commonEntity) throws TenantDataSource {
        TableSql tableSql = iTableSqlService.selectTableSqlByTSqlKey(commonEntity.getQueryMap().get("sqlkey").toString());
        System.err.println(tableSql);
        startPage();  // 校验是否sqlserver 否执行 是执行另一种方式的分页
        return getDataTable(commonService.queryGroupTableList(commonEntity, tableSql));
    }

    /**
     * 通用动态表单详情
     */
    @GetMapping("/dragTableInfo")
    public AjaxResult dragTableInfo(CommonEntity commonEntity) {
      return   AjaxResult.success(dragTableService.dragTableInfo(commonEntity.getQueryMap().get("tableKey").toString()));
    }

    @GetMapping("/dragGroupTableInfo")
    public AjaxResult dragGroupTableInfo(CommonEntity commonEntity) {
        return   AjaxResult.success(dragTableGroupService.selectDragTableGroup(commonEntity.getQueryMap().get("groupKey").toString()));
    }

    /**
     * 动态表单预览接口
     */
    @GetMapping("/dragTablePreview")
    public TableDataInfo DragTablePreview(CommonEntity commonEntity) {
        startPage();
        return getDataTable(commonService.dragTablePreview(commonEntity));
    }

    /**
     * 处理按钮通用接口（新增、修改、删除）
     */
    @PostMapping("/commonBtnHandle")
    public AjaxResult commonBtnHandle(@RequestBody CommonEntity commonEntity) throws JsonProcessingException {
        //按钮类型
        Long btnType = Long.valueOf(commonEntity.getBasicMap().get("btnType").toString());
        //是否开启弹窗
        String visible = commonEntity.getBasicMap().get("visible").toString();
        /*
        * 判断什么类型走什么接口:
        * btnType  10：新增、8：修改、9：删除、5：脚本
        * visible  false代表弹窗未开启时走回显表单模板及数据信息接口；true代表弹窗开启时走保存数据接口
        * */
        if (btnType == ButtonTypeConstants.INSERT && visible.equals("true")) {
            return toAjax(commonService.batchInsert(commonEntity));
        } else if (btnType == ButtonTypeConstants.INSERT && visible.equals("false")) {
            String sqlKey = commonEntity.getBasicMap().get("sqlKey").toString();
            return success(dragFormService.selectDragFormBySqlKey(sqlKey));
        } else if (btnType == ButtonTypeConstants.UPDATE && visible.equals("true")) {
            return toAjax(commonService.edit(commonEntity));
        } else if (btnType == ButtonTypeConstants.UPDATE && visible.equals("false")) {
            Map<String,Object> map = new HashMap<>();
            //获取模板信息
            String sqlKey = commonEntity.getBasicMap().get("sqlKey").toString();
            DragForm dragForm = dragFormService.selectDragFormBySqlKey(sqlKey);
            map.put("template",dragForm);
            //返回结果
            map.put("result",commonService.getInfoById(commonEntity));
            return success(map);
        } else if (btnType == ButtonTypeConstants.DELETE) {
            return toAjax(commonService.batchDelete(commonEntity));
        } else if(btnType == ButtonTypeConstants.SCRIPT) {
        }
        return warn("暂不支持该操作！");
    }
}
