package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.system.entity.DragTableBtnRelevance;
import com.ruoyi.system.entity.vo.DragTableVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.DragTableBtnRelevanceMapper;
import com.ruoyi.system.service.IDragTableBtnRelevanceService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 动态格和动态格按钮关联Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-11-09
 */
@Service
public class DragTableBtnRelevanceServiceImpl implements IDragTableBtnRelevanceService 
{
    @Autowired
    private DragTableBtnRelevanceMapper dragTableBtnRelevanceMapper;

    /**
     * 查询动态格和动态格按钮关联
     * 
     * @param tableKey 动态格和动态格按钮关联主键
     * @return 动态格和动态格按钮关联
     */
    @Override
    public DragTableBtnRelevance selectDragTableBtnRelevanceByTableKey(String tableKey)
    {
        return dragTableBtnRelevanceMapper.selectDragTableBtnRelevanceByTableKey(tableKey);
    }

    /**
     * 查询动态格和动态格按钮关联列表
     * 
     * @param dragTableBtnRelevance 动态格和动态格按钮关联
     * @return 动态格和动态格按钮关联
     */
    @Override
    public List<DragTableBtnRelevance> selectDragTableBtnRelevanceList(DragTableBtnRelevance dragTableBtnRelevance)
    {
        return dragTableBtnRelevanceMapper.selectDragTableBtnRelevanceList(dragTableBtnRelevance);
    }

    /**
     * 新增动态格和动态格按钮关联
     * 
     * @param dragTableBtnRelevanceList 动态格和动态格按钮关联
     * @return 结果
     */
    @Override
    public int batchInsertDragTableBtnRelevance(List<DragTableBtnRelevance> dragTableBtnRelevanceList)
    {
        return dragTableBtnRelevanceMapper.batchInsertDragTableBtnRelevance(dragTableBtnRelevanceList);
    }

    /**
     * 修改动态格和动态格按钮关联
     * 
     * @param dragTableVo 动态格和动态格VO
     * @return 结果
     */
    @Override
    @Transactional
    public void updateDragTableBtnRelevance(DragTableVo dragTableVo)
    {
        // delete
        dragTableBtnRelevanceMapper.deleteDragTableBtnRelevanceByTableKey(dragTableVo.getTableKey());
        // insert
        if(dragTableVo.getDragTableBtnRelevanceList().size() > 0){
            dragTableBtnRelevanceMapper.batchInsertDragTableBtnRelevance(dragTableVo.getDragTableBtnRelevanceList());
        }
    }

    /**
     * 批量删除动态格和动态格按钮关联
     * 
     * @param tableKeys 需要删除的动态格和动态格按钮关联主键
     * @return 结果
     */
    @Override
    public int deleteDragTableBtnRelevanceByTableKeys(List<String> tableKeys)
    {
        return dragTableBtnRelevanceMapper.deleteDragTableBtnRelevanceByTableKeys(tableKeys);
    }

    /**
     * 删除动态格和动态格按钮关联信息
     * 
     * @param tableKey 动态格和动态格按钮关联主键
     * @return 结果
     */
    @Override
    public int deleteDragTableBtnRelevanceByTableKey(String tableKey)
    {
        return dragTableBtnRelevanceMapper.deleteDragTableBtnRelevanceByTableKey(tableKey);
    }
}
