package com.ruoyi.system.service.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.entity.DragTable;
import com.ruoyi.system.entity.DragTableCondition;
import com.ruoyi.system.entity.DragTableGroup;
import com.ruoyi.system.entity.TableSql;
import com.ruoyi.system.entity.vo.DragTableGroupVo;
import com.ruoyi.system.entity.vo.DragTableVo;
import com.ruoyi.system.mapper.DragTableConditionMapper;
import com.ruoyi.system.mapper.DragTableGroupMapper;
import com.ruoyi.system.mapper.DragTableMapper;
import com.ruoyi.system.mapper.TableSqlMapper;
import com.ruoyi.system.service.IDragTableGroupService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.parameters.P;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @author hmc
 * @date 2023-11-01 14:27
 * @Description:
 */

@Service
public class DragTableGroupServiceImpl implements IDragTableGroupService {

    @Autowired
    private DragTableGroupMapper dragTableGroupMapper;

    @Autowired
    private DragTableMapper dragTableMapper;

    @Autowired
    private DragTableServiceImpl dragTableService;

    @Autowired
    private DragTableConditionMapper dragTableConditionMapper;

    @Autowired
    private TableSqlMapper tableSqlMapper;

    /**
     * 查询拖拽格组
     *
     * @param id 拖拽格组主键
     * @return 拖拽格组
     */
    @Override
    public DragTableGroup selectDragTableGroupById(Long id)
    {
        return dragTableGroupMapper.selectDragTableGroupById(id);
    }

    /**
     * 查询拖拽格组列表
     *
     * @param dragTableGroup 拖拽格组
     * @return 拖拽格组
     */
    @Override
    public List<DragTableGroup> selectDragTableGroupList(DragTableGroup dragTableGroup)
    {
        return dragTableGroupMapper.selectDragTableGroupList(dragTableGroup);
    }


    /**
     * 新增拖拽格组
     *
     * @param dragTableGroupVo 拖拽格组
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertDragTableGroup(DragTableGroupVo dragTableGroupVo)
    {
        //表格组实体类拷贝数据
        DragTableGroup dragTableGroup=new DragTableGroup();
        BeanUtils.copyProperties(dragTableGroupVo,dragTableGroup);
        //添加动态表格列表
        dragTableService.addDragTable(dragTableGroupVo);
        return dragTableGroupMapper.insertDragTableGroup(dragTableGroup);
    }

    // SQL 条件的开始
    public static final String SQL_START = "CONCAT(";

    // SQL 超级查询常量
    public static final String SQL_MIDDLE = "IFNULL( #{VAL}, '' )";

    // sqlserver || DM 数据类型的超级查询常量
    public static final String SQL_DM_SERVER_MIDDLE = "COALESCE( #{VAL}, '' )";

    // SQL 条件的结束
    public static final String SQL_END = "LIKE '%#{val}%'";

    /**
     * 修改拖拽格组
     *
     * @param dragTableGroupVo 拖拽格组
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateDragTableGroup(DragTableGroupVo dragTableGroupVo) {
        //根据id查询表格组信息
        DragTableGroup dragTableGroupOne = dragTableGroupMapper.selectDragTableGroupById(dragTableGroupVo.getId());
        //得到group_table_info
        String groupTableInfo = dragTableGroupOne.getGroupTableInfo();
        //把他转换成Map对象
        JSONArray jsonArray = JSON.parseArray(groupTableInfo);
        //收集tableKey
        List<String> tableKeys = jsonArray.stream().map(item -> JSONObject.parseObject(item.toString()).get("tableKey").toString()
        ).collect(Collectors.toList());
        //删除条件数据
        List<Long> dragTableIds = dragTableMapper.selectDragTableTableKeys(tableKeys)
                .stream().map(item -> item.gettId()).collect(Collectors.toList());
        dragTableConditionMapper.deleteDragTableConditionBytIds(dragTableIds);
        //删除sql数据
        //Long[] dragTableIds1 = dragTableIds.toArray(new Long[0]);
        //tableSqlMapper.deleteTableSqlByTIds(dragTableIds1);
        //删除表格数据
        //dragTableMapper.deleteDragTableByTableKeys(tableKeys);

        //优化逻辑 1、表格组信息 2、表格信息、条件信息、sql信息
        List<DragTableVo> dragTables = dragTableGroupVo.getDragTables();
        if (dragTables.size()>0) {
            dragTables.stream().forEach(dragTableVo->{
                String SQL="";
                //add drag_table
                DragTable dragTable = new DragTable();
                BeanUtils.copyProperties(dragTableVo, dragTable);
                dragTable.setDtColumnName(JSON.toJSONString(dragTableVo.getDtColumnName()));
                dragTable.setPrimaryKey(dragTableVo.getPrimaryKey());
                dragTable.setMenuId(dragTableVo.getMenuId());
                dragTable.setDtType("1");
                //add table_sql
                TableSql tableSql = new TableSql();
                tableSql.settId(dragTable.gettId());
                tableSql.setTableSql(dragTableVo.getTableSql());
                dragTableMapper.updateDragTable(dragTable);
                //拼接sql查询条件
                switch (SecurityUtils.getDatabaseType().toUpperCase()) {
                    case "MYSQL":
                        for (int i = 0; dragTableVo.getSearchFieldList().size() > i; i++) {
                            SQL += " AND "+dragTableVo.getSearchFieldList().get(i)+"="+dragTableVo.getConditionDefaultValueMap().get(dragTableVo.getSearchFieldList().get(i));
                        }
                        break;
                    case "DM":
                    case "SQLSERVER":
                        SQL += SQL_START;
                        for (int i = 0; dragTableVo.getSearchFieldList().size() > i; i++) {
                            SQL += SQL_DM_SERVER_MIDDLE.replace("#{VAL}", dragTableVo.getSearchFieldList().get(i));
                            SQL += dragTableVo.getSearchFieldList().size() - 1 == i ? ",'')" : ",\n";
                        }
                        break;
                    case "ORACLE":
                        //SQL_START = "";
                        for (int i = 0; dragTableVo.getSearchFieldList().size() > i; i++) {
                            SQL += dragTableVo.getSearchFieldList().get(i);
                            SQL += (dragTableVo.getSearchFieldList().size() - 1 == i ? " " : "||");
                        }
                        break;
                }
                String where = dragTableVo.getDtTableName() + ".del_flag = '0'";
                tableSql.setTableCondition(where + SQL);
                tableSql.setTableAlias(dragTableVo.getDtTableName());
                tableSql.setTableExportField(JSON.toJSONString(dragTableVo.getTableExportField()));
                tableSql.setSqlKey(dragTableVo.getSqlKey());
                tableSql.setOrderByColumn(dragTableVo.getOrderByColumn());
                tableSql.setSortOrder(dragTableVo.getSortOrder());
                tableSqlMapper.updateTableSql(tableSql);
                //add drag_table_condition
                if (dragTableVo.getSearchFieldList().size() > 0) {
                    List<DragTableCondition> dragTableConditionList = new ArrayList<>();
                    dragTableVo.getSearchFieldList().forEach(item -> {
                        dragTableConditionList.add(new DragTableCondition(dragTable.gettId(), item,dragTableVo.getConditionDefaultValueMap().get(item).toString()));
                    });
                    dragTableConditionMapper.insertDragTableConditionByList(dragTableConditionList);
                }
            });
        }
        //修改表格组列表信息
        DragTableGroup dragTableGroup = new DragTableGroup();
        BeanUtils.copyProperties(dragTableGroupVo, dragTableGroup);
        int i = dragTableGroupMapper.updateDragTableGroup(dragTableGroup);
        //从新插入数据
        //dragTableService.addDragTable(dragTableGroupVo);
        return i;
    }

    /**
     * 批量删除拖拽格组
     *
     * @param ids 需要删除的拖拽格组主键
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteDragTableGroupByIds(Long[] ids)
    {
        //表格数据
        List<String> tableKeys = new ArrayList<>();
        //删除条件数据
        List<Long> dragTableIds =new ArrayList<>();
        for (Long id : ids) {
            //根据id查询表格组信息
            DragTableGroup dragTableGroupOne = dragTableGroupMapper.selectDragTableGroupById(id);
            //得到group_table_info
            String groupTableInfo = dragTableGroupOne.getGroupTableInfo();
            //把他转换成Map对象
            JSONArray jsonArray = JSON.parseArray(groupTableInfo);
            //收集tableKey
            jsonArray.stream().forEach(item->
                    tableKeys.add(JSONObject.parseObject(item.toString()).get("tableKey").toString()));
            //删除条件数据
            dragTableMapper.selectDragTableTableKeys(tableKeys)
                    .stream().forEach(item ->dragTableIds.add(item.gettId()));
        }
        //删除表格数据
        dragTableMapper.deleteDragTableByTableKeys(tableKeys);
        //删除条件数据
        dragTableConditionMapper.deleteDragTableConditionBytIds(dragTableIds);
        //删除sql数据
        Long[] dragTableIds1 = dragTableIds.toArray(new Long[0]);
        tableSqlMapper.deleteTableSqlByTIds(dragTableIds1);
        //删除组数据
        return dragTableGroupMapper.deleteDragTableGroupByIds(ids);
    }


    /**
     * 根据表格组key查询表格组信息
     * @param groupKey
     * @return
     */
    @Override
    public String selectDragTableGroup(String groupKey) {
        String groupTableInfo = dragTableGroupMapper.selectDragTableGroupByGroupKey(groupKey);
        return groupTableInfo;
    }

    @Override
    public DragTableGroupVo selectDragTableGroupListDetail(DragTableGroup dragTableGroup) {
        //根据id查询表格组信息
        DragTableGroup dragTableGroupOne = dragTableGroupMapper.selectDragTableGroupById(dragTableGroup.getId());
        //得到group_table_info
        String groupTableInfo = dragTableGroupOne.getGroupTableInfo();
        //把他转换成Map对象
        JSONArray jsonArray = JSON.parseArray(groupTableInfo);
        List<String> stringList=new ArrayList<>();
        //收集下tableKey
        jsonArray.forEach(e->{
            JSONObject jsonObject = JSON.parseObject(e.toString());
            String str = jsonObject.get("tableKey").toString();
            stringList.add(str);
        });
        //根据tableKey批量查询表格数据
        List<DragTableVo> dragTables = dragTableMapper.selectDragTableTableKeys(stringList).stream().map(item -> {
            //拿到这个表格的所有条件数据
            List<DragTableCondition> dragTableConditions = dragTableConditionMapper.selectDragTableConditionByTid(item.gettId());
            //条件
            item.setSearchFieldList(dragTableConditions.stream().map(it->it.getConditionField()).collect(Collectors.toList()));
            //绑定的默认值map
            HashMap<String, Object> conditionDefaultValueMap = new HashMap<>();
            //关联条件
            dragTableConditions.forEach(condition -> {
                if (condition.getConditionDefaultValue() != null && condition.getConditionDefaultValue() != "") {
                    //条件字段：条件值
                    conditionDefaultValueMap.put(condition.getConditionField(), condition.getConditionDefaultValue());
                    item.setConditionDefaultValueMap(conditionDefaultValueMap);
                }
            });
            return item;
        }).collect(Collectors.toList());
        DragTableGroupVo dragTableGroupVo=new DragTableGroupVo();
        BeanUtils.copyProperties(dragTableGroupOne, dragTableGroupVo);
        dragTableGroupVo.setDragTables(dragTables);
        //查询表格的关联数据
        return    dragTableGroupVo;
    }

    @Override
    public Boolean selectDragTableGroupTableListSize(Long[] ids) {
        List<DragTableGroup> dragTableGroups = dragTableGroupMapper.selectDragTableGroupByIdIn(ids);
        List<String> tableKeys=new ArrayList<>();
        //收集这个组下的所有tableKey
        dragTableGroups.stream().forEach(item->{
            JSONArray jsonArray = JSON.parseArray(item.getGroupTableInfo());
            jsonArray.stream().forEach(
                    it ->{
                        tableKeys.add( JSONObject.parseObject(it.toString()).get("tableKey").toString());
                    }
            );
        });
        //判断tableKey在表格表中出现了吗
        List<DragTableVo> dragTableVos = dragTableMapper.selectDragTableTableKeys(tableKeys);
        if(dragTableVos.size()>0){
            return  false;
        }
        return true;
    }


}
